Module candidate

Module candidate 

Row-oriented candidate storage and conversion utilities.

Traits

CandidateData
Basic trait for the work with the candidate data This trait is used to store and retrive the data for the candidates