Module dataframe

Module dataframe 

Modules

column_store
index
join
key
python

Structs

DataFrame
DataFrame holds information about ColumnFrame. This is used to store the data and the metadata for the candidates.

Enums

TopN
Controls how many rows to take from a sorted dataframe.