Module column_store

Module column_store 

Column-oriented storage, typed arrays, and frame operations.

Modules

filter_df
Expression-based row filtering applied to a ColumnFrame.
sorted_df
Sorted-view wrapper over a ColumnFrame for top-N queries.
typed_array
Typed column storage (TypedData) and nullable wrapper (TypedDataArray). Column-oriented typed storage for ColumnFrame.

Structs

ColumnFrame
Column-oriented in-memory store for candidate data.
KeyIndex
KeyIndex is used to store the keys for the super::ColumnFrame The keys are stored in the order they are added - the order is preserved The keys are stored in the Vec and the indexes are stored in the HashMap The indexes are used to access the data in the super::ColumnFrame by the column Key NOTE: The keys are unique - if the key is already present, it will be removed

Enums

MaybeView
Either a borrowed ArrayView2 or an owned Array2 of DataValue.

Functions

convert_data_value
Converts a DataValue to the canonical representation for the given crate::DataType.
convert_dv_to_dtype
Converts a DataValue to match the dtype declared by the column Key.