pub fn convert_data_value(item: DataValue, dtype: DataType) -> DataValueExpand description
Converts a DataValue to the canonical representation for the given crate::DataType.
Uses the Extract trait for numeric coercion. If dtype is crate::DataType::Unknown
and the value is not Null, the type is auto-detected and conversion retried.