Column key type with name, id, and data-type metadata.
Structs
- Key
Keyholds information about key. It’s used to identify the feature Mostly is represented as a string but inside is stored as a hash and theDataTypeof the feature/value which is stored incrate::DataFrame