Module filter

Module filter 

Expression-based row filtering for dataframes.

Re-exports

pub use filtering::*;

Modules

error
Filter-specific error types.
filtering
Operator matching and function-based filtering logic.

Structs

Expression
A single filter comparison: left operator right.
FilterRules
Parsed filter expression tree, ready to be evaluated against a data source.

Enums

DataInput
One side of a filter expression — a literal value, column key, or function call.
FilterArgument
The right-hand side of a filter expression, resolved to a concrete form.
FilterCombinantion
A tree of filter expressions connected by && / || operators.
FilterJoin
The operators for filtering functions
FilterOperator
The operators for filtering functions
Function
Built-in column functions usable in filter expressions (e.g. .len()).
Rule

Traits

Filtering
Trait for data sources that can evaluate filter expressions.