Row-oriented candidate storage and conversion utilities.
Traits
- Candidate
Data - Basic trait for the work with the candidate data This trait is used to store and retrive the data for the candidates
Row-oriented candidate storage and conversion utilities.