Column-oriented storage, typed arrays, and frame operations.
Modules
- filter_
df - Expression-based row filtering applied to a
ColumnFrame. - sorted_
df - Sorted-view wrapper over a
ColumnFramefor top-N queries. - typed_
array - Typed column storage (
TypedData) and nullable wrapper (TypedDataArray). Column-oriented typed storage forColumnFrame.
Structs
- Column
Frame - Column-oriented in-memory store for candidate data.
- KeyIndex
KeyIndexis used to store the keys for thesuper::ColumnFrameThe keys are stored in the order they are added - the order is preserved The keys are stored in theVecand the indexes are stored in theHashMapThe indexes are used to access the data in thesuper::ColumnFrameby the columnKeyNOTE: The keys are unique - if the key is already present, it will be removed
Enums
- Maybe
View - Either a borrowed
ArrayView2or an ownedArray2ofDataValue.
Functions
- convert_
data_ value - Converts a
DataValueto the canonical representation for the givencrate::DataType. - convert_
dv_ to_ dtype - Converts a
DataValueto match the dtype declared by the columnKey.