Expression-based row filtering for dataframes.
Re-exports
pub use filtering::*;
Modules
Structs
- Expression
- A single filter comparison:
left operator right. - Filter
Rules - Parsed filter expression tree, ready to be evaluated against a data source.
Enums
- Data
Input - One side of a filter expression — a literal value, column key, or function call.
- Filter
Argument - The right-hand side of a filter expression, resolved to a concrete form.
- Filter
Combinantion - A tree of filter expressions connected by
&&/||operators. - Filter
Join - The operators for filtering functions
- Filter
Operator - The operators for filtering functions
- Function
- Built-in column functions usable in filter expressions (e.g.
.len()). - Rule
Traits
- Filtering
- Trait for data sources that can evaluate filter expressions.